.. _spider_usenix.org:

usenix.org
----------
Newest issues of the Usenix Magazine ;login:.

Configuration
~~~~~~~~~~~~~
Add ``usenix.org`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     usenix.org

